@@ -139,6 +139,7 @@ def vf_vmap() -> dict[str, str]:
         "rss_sort",
         "rss_fmt_t",
         "rss_fmt_d",
+        "rw_edit",
         "shr_who",
         "sort",
         "tail_fd",
@@ -147,6 +148,7 @@ def vf_vmap() -> dict[str, str]:
         "tail_who",
         "tcolor",
         "th_qv",
+        "th_qvx",
         "th_spec_p",
         "txt_eol",
         "unlist",
@@ -306,7 +308,8 @@ flagcats = {
         "thsize": "thumbnail res; WxH",
         "crop": "center-cropping (y/n/fy/fn)",
         "th3x": "3x resolution (y/n/fy/fn)",
-        "th_qv=40": "thumbnail quality (10~90)",
+        "th_qv=40": "webp/jpg thumbnail quality (10~90)",
+        "th_qvx=40": "jxl thumbnail quality (10~90)",
         "convt": "convert-to-image timeout in seconds",
         "aconvt": "convert-to-audio timeout in seconds",
         "th_spec_p=1": "make spectrograms? 0=never 1=fallback 2=always",
@@ -389,6 +392,7 @@ flagcats = {
         "opds_exts": "file formats to list in OPDS feeds; leave empty to show everything",
     },
     "textfiles": {
+        "rw_edit=md,txt": "only require read+write to edit .md and .txt",
         "md_no_br": "newline only on double-newline or two tailing spaces",
         "md_hist": "where to put markdown backups; s=subfolder, v=volHist, n=nope",
         "exp": "enable textfile expansion; see --help-exp",
