@@ -35,14 +35,14 @@ from .mtag import HAVE_FFMPEG, HAVE_FFPROBE, HAVE_MUTAGEN
 from .pwhash import HAVE_ARGON2
 from .tcpsrv import TcpSrv
 from .th_srv import (
-    HAVE_AVIF,
+    H_PIL_AVIF,
+    H_PIL_HEIF,
+    H_PIL_WEBP,
     HAVE_FFMPEG,
     HAVE_FFPROBE,
-    HAVE_HEIF,
     HAVE_PIL,
     HAVE_RAW,
     HAVE_VIPS,
-    HAVE_WEBP,
     ThumbSrv,
 )
 from .up2k import Up2k
@@ -371,10 +371,6 @@ class SvcHub(object):
             t = ", ".join(self.args.th_dec) or "(None available)"
             self.log("thumb", "decoder preference: {}".format(t))
 
-            if "pil" in self.args.th_dec and not HAVE_WEBP:
-                msg = "disabling webp thumbnails because either libwebp is not available or your Pillow is too old"
-                self.log("thumb", msg, c=3)
-
             if self.args.th_dec:
                 self.thumbsrv = ThumbSrv(self)
             else:
@@ -954,14 +950,14 @@ class SvcHub(object):
             (HAVE_SQLITE3, "sqlite", "sessions and file/media indexing"),
             (HAVE_PIL, "pillow", "image thumbnails (plenty fast)"),
             (HAVE_VIPS, "vips", "image thumbnails (faster, eats more ram)"),
-            (HAVE_WEBP, "pillow-webp", "create thumbnails as webp files"),
+            (H_PIL_WEBP, "pillow-webp", "create thumbnails as webp files"),
             (HAVE_FFMPEG, "ffmpeg", t_ff + ", good-but-slow image thumbnails"),
             (HAVE_FFPROBE, "ffprobe", t_ff + ", read audio/media tags"),
             (HAVE_MUTAGEN, "mutagen", "read audio tags (ffprobe is better but slower)"),
             (HAVE_ARGON2, "argon2", "secure password hashing (advanced users only)"),
             (HAVE_ZMQ, "pyzmq", "send zeromq messages from event-hooks"),
-            (HAVE_HEIF, "pillow-heif", "read .heif images with pillow (rarely useful)"),
-            (HAVE_AVIF, "pillow-avif", "read .avif images with pillow (rarely useful)"),
+            (H_PIL_HEIF, "pillow-heif", "read .heif pics with pillow (rarely useful)"),
+            (H_PIL_AVIF, "pillow-avif", "read .avif pics with pillow (rarely useful)"),
             (HAVE_RAW, "rawpy", "read RAW images"),
         ]
         if ANYWIN:
@@ -1081,6 +1077,12 @@ class SvcHub(object):
             vs = [x.lower() for x in vs]
             setattr(al, n, vs)
 
+        ns = "ihead ohead"
+        for n in ns.split(" "):
+            vs = getattr(al, n) or []
+            vs = [x.lower() for x in vs]
+            setattr(al, n, vs)
+
         R = al.rp_loc
         if "//" in R or ":" in R:
             t = "found URL in --rp-loc; it should be just the location, for example /foo/bar"
@@ -1154,10 +1156,11 @@ class SvcHub(object):
         elif al.ban_url == "no":
             al.sus_urls = None
 
-        al.xff_hdr = al.xff_hdr.lower()
+        zs = "fika idp_h_grp idp_h_key pw_hdr pw_urlp xf_host xf_proto xf_proto_fb xff_hdr"
+        for k in zs.split(" "):
+            setattr(al, k, str(getattr(al, k)).lower().strip())
+
         al.idp_h_usr = [x.lower() for x in al.idp_h_usr or []]
-        al.idp_h_grp = al.idp_h_grp.lower()
-        al.idp_h_key = al.idp_h_key.lower()
 
         al.idp_hm_usr_p = {}
         for zs0 in al.idp_hm_usr or []:
