@@ -36,7 +36,7 @@ from .util import (
 )
 
 if True:  # pylint: disable=using-constant-test
-    from typing import Any, Optional, Union
+    from typing import Any, Callable, Optional, Union
 
 if TYPE_CHECKING:
     from .svchub import SvcHub
@@ -46,11 +46,14 @@ if PY2:
 
 HAVE_PIL = False
 HAVE_PILF = False
-HAVE_HEIF = False
-HAVE_AVIF = False
-HAVE_WEBP = False
+H_PIL_HEIF = False
+H_PIL_AVIF = False
+H_PIL_WEBP = False
+H_PIL_JXL = False
 
-EXTS_TH = set(["jpg", "webp", "png"])
+TH_CH = {"j": "jpg", "p": "png", "w": "webp", "x": "jxl"}
+
+EXTS_TH = set(["jpg", "webp", "jxl", "png"])
 EXTS_AC = set(["opus", "owa", "caf", "mp3", "flac", "wav"])
 EXTS_SPEC_SAFE = set("aif aiff flac mp3 opus wav".split())
 
@@ -128,7 +131,21 @@ try:
             raise Exception()
 
         Image.new("RGB", (2, 2)).save(BytesIO(), format="webp")
-        HAVE_WEBP = True
+        H_PIL_WEBP = True
+    except:
+        pass
+
+    try:
+        if os.environ.get("PRTY_NO_PIL_JXL"):
+            raise Exception()
+
+        try:
+            import pillow_jxl
+        except ImportError:
+            pass
+
+        Image.new("RGB", (2, 2)).save(BytesIO(), format="jxl")
+        H_PIL_JXL = True
     except:
         pass
 
@@ -142,7 +159,7 @@ try:
             from pyheif_pillow_opener import register_heif_opener
 
         register_heif_opener()
-        HAVE_HEIF = True
+        H_PIL_HEIF = True
     except:
         pass
 
@@ -151,12 +168,12 @@ try:
             raise Exception()
 
         if ".avif" in Image.registered_extensions():
-            HAVE_AVIF = True
+            H_PIL_AVIF = True
             raise Exception()
 
         import pillow_avif  # noqa: F401  # pylint: disable=unused-import
 
-        HAVE_AVIF = True
+        H_PIL_AVIF = True
     except:
         pass
 
@@ -171,6 +188,7 @@ try:
     HAVE_VIPS = True
     import pyvips
 
+    pyvips.cache_set_max(0)
     logging.getLogger("pyvips").setLevel(logging.WARNING)
 except Exception as e:
     HAVE_VIPS = False
@@ -203,7 +221,7 @@ def thumb_path(histpath: str, rem: str, mtime: float, fmt: str, ffa: set[str]) -
 
     # spectrograms are never cropped; strip fullsize flag
     ext = rem.split(".")[-1].lower()
-    if ext in ffa and fmt[:2] in ("wf", "jf"):
+    if ext in ffa and fmt[:2] in ("wf", "jf", "xf"):
         fmt = fmt.replace("f", "")
 
     dcache = th_dir_cache
@@ -224,8 +242,7 @@ def thumb_path(histpath: str, rem: str, mtime: float, fmt: str, ffa: set[str]) -
     if fmt in EXTS_AC:
         cat = "ac"
     else:
-        fc = fmt[:1]
-        fmt = "webp" if fc == "w" else "png" if fc == "p" else "jpg"
+        fmt = TH_CH[fmt[:1]]
         cat = "th"
 
     return "%s/%s/%s/%s.%x.%s" % (histpath, cat, rd, fn, int(mtime), fmt)
@@ -292,14 +309,22 @@ class ThumbSrv(object):
             ]
         ]
 
-        if not HAVE_HEIF:
+        if not H_PIL_HEIF:
             for f in "heif heifs heic heics".split(" "):
                 self.fmt_pil.discard(f)
 
-        if not HAVE_AVIF:
+        if not H_PIL_AVIF:
             for f in "avif avifs".split(" "):
                 self.fmt_pil.discard(f)
 
+        if not H_PIL_WEBP:
+            for f in "webp".split(" "):
+                self.fmt_pil.discard(f)
+
+        if not H_PIL_JXL:
+            for f in "jxl".split(" "):
+                self.fmt_pil.discard(f)
+
         self.thumbable: set[str] = set()
 
         if "pil" in self.args.th_dec:
@@ -407,7 +432,7 @@ class ThumbSrv(object):
         zs = "th_dec th_no_webp th_no_jpg"
         for zs in zs.split(" "):
             ret.append("%s(%s)\n" % (zs, getattr(self.args, zs)))
-        zs = "th_qv thsize th_spec_p convt"
+        zs = "th_qv th_qvx thsize th_spec_p convt"
         for zs in zs.split(" "):
             ret.append("%s(%s)\n" % (zs, vn.flags.get(zs)))
         return "".join(ret)
@@ -489,7 +514,7 @@ class ThumbSrv(object):
                         ext in self.fmt_ffa or ext in self.fmt_ffv
                     )
 
-                    if lib == "pil" and ext in self.fmt_pil:
+                    if lib == "pil" and ext in self.fmt_pil and tex in self.fmt_pil:
                         funs.append(self.conv_pil)
                     elif lib == "vips" and ext in self.fmt_vips:
                         funs.append(self.conv_vips)
@@ -621,7 +646,8 @@ class ThumbSrv(object):
             im.thumbnail(self.getres(vn, fmt))
 
         fmts = ["RGB", "L"]
-        args = {"quality": vn.flags["th_qv"]}
+        zs = "th_qvx" if tpath.endswith(".jxl") else "th_qv"
+        args = {"quality": vn.flags[zs]}
 
         if tpath.endswith(".webp"):
             # quality 80 = pillow-default
@@ -646,8 +672,9 @@ class ThumbSrv(object):
         with Image.open(fsenc(abspath)) as im:
             self.conv_image_pil(im, tpath, fmt, vn)
 
-    def conv_vips(self, abspath: str, tpath: str, fmt: str, vn: VFS) -> None:
-        self.wait4ram(0.2, tpath)
+    def conv_image_vips(
+        self, loader: "Callable[[int, dict], Any]", tpath: str, fmt: str, vn: VFS
+    ) -> None:
         crops = ["centre", "none"]
         if "f" in fmt:
             crops = ["none"]
@@ -655,10 +682,11 @@ class ThumbSrv(object):
         w, h = self.getres(vn, fmt)
         kw = {"height": h, "size": "down", "intent": "relative"}
 
+        img = None
         for c in crops:
             try:
                 kw["crop"] = c
-                img = pyvips.Image.thumbnail(abspath, w, **kw)
+                img = loader(w, kw)
                 break
             except:
                 if c == crops[-1]:
@@ -670,7 +698,20 @@ class ThumbSrv(object):
         if tpath.endswith("jpg"):
             qv = VIPS_JPG_Q[qv // 5]
             args["optimize_coding"] = True
+        elif tpath.endswith("jxl"):
+            qv = vn.flags["th_qvx"]
+            # args["effort"] = 8
+            #  `- not worth it; twice as slow, size drops 12%, no visual improvement unlike ffmpeg
         img.write_to_file(tpath, Q=qv, strip=True, **args)
+        img.invalidate()
+
+    def conv_vips(self, abspath: str, tpath: str, fmt: str, vn: VFS) -> None:
+        self.wait4ram(0.2, tpath)
+
+        def _loader(w: int, kw: dict) -> Any:
+            return pyvips.Image.thumbnail(abspath, w, **kw)
+
+        self.conv_image_vips(_loader, tpath, fmt, vn)
 
     def conv_raw(self, abspath: str, tpath: str, fmt: str, vn: VFS) -> None:
         self.wait4ram(0.2, tpath)
@@ -682,34 +723,15 @@ class ThumbSrv(object):
             with open(tpath, "wb") as f:
                 f.write(thumb.data)
         if HAVE_VIPS:
-            crops = ["centre", "none"]
-            if "f" in fmt:
-                crops = ["none"]
-            w, h = self.getres(vn, fmt)
-            kw = {"height": h, "size": "down", "intent": "relative"}
 
-            for c in crops:
-                try:
-                    kw["crop"] = c
-                    if thumb.format == rawpy.ThumbFormat.BITMAP:
-                        img = pyvips.Image.new_from_array(
-                            thumb.data, interpretation="rgb"
-                        )
-                        img = img.thumbnail_image(w, **kw)
-                    else:
-                        img = pyvips.Image.thumbnail_buffer(thumb.data, w, **kw)
-                    break
-                except:
-                    if c == crops[-1]:
-                        raise
+            def _loader(w: int, kw: dict) -> Any:
+                if thumb.format == rawpy.ThumbFormat.BITMAP:
+                    img = pyvips.Image.new_from_array(thumb.data, interpretation="rgb")
+                    return img.thumbnail_image(w, **kw)
+                else:
+                    return pyvips.Image.thumbnail_buffer(thumb.data, w, **kw)
 
-            assert img  # type: ignore  # !rm
-            args = {}
-            qv = vn.flags["th_qv"]
-            if tpath.endswith("jpg"):
-                qv = VIPS_JPG_Q[qv // 5]
-                args["optimize_coding"] = True
-            img.write_to_file(tpath, Q=qv, strip=True, **args)
+            self.conv_image_vips(_loader, tpath, fmt, vn)
         elif HAVE_PIL:
             if thumb.format == rawpy.ThumbFormat.BITMAP:
                 im = Image.fromarray(thumb.data, "RGB")
@@ -770,11 +792,21 @@ class ThumbSrv(object):
         ]
         # fmt: on
 
+        self._ffmpeg_im_o(tpath, vn, cmd)
+
+    def _ffmpeg_im_o(self, tpath: str, vn: VFS, cmd: list[bytes]) -> None:
         if tpath.endswith(".jpg"):
             cmd += [
                 b"-q:v",
                 FF_JPG_Q[vn.flags["th_qv"] // 5],  # default=??
             ]
+        elif tpath.endswith(".jxl"):
+            cmd += [
+                b"-q:v",
+                unicode(vn.flags["th_qvx"]).encode("ascii"),  # default=??
+                b"-effort:v",
+                b"8",  # default=7, 1=fast, 9=max, 9~=8 but slower
+            ]
         else:
             cmd += [
                 b"-q:v",
@@ -979,21 +1011,7 @@ class ThumbSrv(object):
         ]
         # fmt: on
 
-        if tpath.endswith(".jpg"):
-            cmd += [
-                b"-q:v",
-                FF_JPG_Q[vn.flags["th_qv"] // 5],  # default=??
-            ]
-        else:
-            cmd += [
-                b"-q:v",
-                unicode(vn.flags["th_qv"]).encode("ascii"),  # default=75
-                b"-compression_level:v",
-                b"6",  # default=4, 0=fast, 6=max
-            ]
-
-        cmd += [fsenc(tpath)]
-        self._run_ff(cmd, vn, "convt")
+        self._ffmpeg_im_o(tpath, vn, cmd)
 
     def conv_mp3(self, abspath: str, tpath: str, fmt: str, vn: VFS) -> None:
         quality = self.args.q_mp3.lower()
