@@ -114,7 +114,7 @@ Ls.grc = {
 	"login": "Σύνδεση", //m
 	"access": " πρόσβαση",
 	"ot_close": "κλείσιμο υπομενού",
-	"ot_search": "αναζήτηση αρχείων με βάση χαρακτηριστικά, διαδρομή / όνομα, μουσικά tags ή οποιονδήποτε συνδυασμό$N$N&lt;code&gt;foo bar&lt;/code&gt; = πρέπει να περιέχει και τα «foo» και «bar»,$N&lt;code&gt;foo -bar&lt;/code&gt; = πρέπει να περιέχει το «foo» αλλά όχι το «bar»,$N&lt;code&gt;^yana .opus$&lt;/code&gt; = να ξεκινά με «yana» και να είναι αρχείο «opus»$N&lt;code&gt;&quot;try unite&quot;&lt;/code&gt; = να περιέχει ακριβώς «try unite»$N$Nη μορφή ημερομηνίας είναι iso-8601, όπως$N&lt;code&gt;2009-12-31&lt;/code&gt; ή &lt;code&gt;2020-09-12 23:30:00&lt;/code&gt;",
+	"ot_search": "`αναζήτηση αρχείων με βάση χαρακτηριστικά, διαδρομή / όνομα, μουσικά tags ή οποιονδήποτε συνδυασμό$N$N`foo bar` = πρέπει να περιέχει και τα «foo» και «bar»,$N`foo -bar` = πρέπει να περιέχει το «foo» αλλά όχι το «bar»,$N`^yana .opus$` = να ξεκινά με «yana» και να είναι αρχείο «opus»$N`&quot;try unite&quot;` = να περιέχει ακριβώς «try unite»$N$Nη μορφή ημερομηνίας είναι iso-8601, όπως$N`2009-12-31` ή `2020-09-12 23:30:00`",
 	"ot_unpost": "unpost: διαγραφή πρόσφατων μεταφορτώσεων ή ακύρωση ανολοκλήρωτων",
 	"ot_bup": "bup: βασικός uploader, υποστηρίζει μέχρι και netscape 4.0",
 	"ot_mkdir": "mkdir: δημιουργία νέου φακέλου",
@@ -263,9 +263,9 @@ Ls.grc = {
 
 	"cdt_lim": "μέγιστος αριθμός αρχείων προς εμφάνιση σε ένα φάκελο",
 	"cdt_ask": "όταν φτάνεις στο τέλος,$Nαντί να φορτώσει περισσότερα αρχεία,$Nρωτά τι να κάνει",
-	"cdt_hsort": "πόσους κανόνες ταξινόμησης (&lt;code&gt;,sorthref&lt;/code&gt;) να συμπεριλάβει σε URLs πολυμέσων. Αν το βάλεις 0 αγνοεί και κανόνες ταξινόμησης στους συνδέσμους πολυμέσων",
-	"cdt_ren": "ενεργοποίηση προσαρμοσμένου μενού δεξιού κλικ, το κανονικό μενού είναι προσβάσιμο με shift + δεξί κλικ", //m
-	"cdt_rdb": "εμφάνιση του κανονικού μενού δεξιού κλικ όταν το προσαρμοσμένο είναι ήδη ανοιχτό και γίνεται ξανά δεξί κλικ", //m
+	"cdt_hsort": "`πόσους κανόνες ταξινόμησης (`,sorthref`) να συμπεριλάβει σε URLs πολυμέσων. Αν το βάλεις 0 αγνοεί και κανόνες ταξινόμησης στους συνδέσμους πολυμέσων",
+	"cdt_ren": "ενεργοποίηση προσαρμοσμένου μενού δεξιού κλικ, το κανονικό μενού είναι προσβάσιμο με shift + δεξί κλικ\">ενεργοποίηση", //m
+	"cdt_rdb": "εμφάνιση του κανονικού μενού δεξιού κλικ όταν το προσαρμοσμένο είναι ήδη ανοιχτό και γίνεται ξανά δεξί κλικ\">x2", //m
 
 	"tt_entree": "εμφάνιση navpane (δέντρο διαδρομών)$NΠλήκτρο συντόμευσης: B",
 	"tt_detree": "εμφάνιση breadcrumbs (καρτέλες διαδρομών)$NΠλήκτρο συντόμευσης: B",
@@ -283,6 +283,7 @@ Ls.grc = {
 	"ml_tint": "φίλτρο χρώματος",
 	"ml_eq": "ισοσταθμιστής ήχου",
 	"ml_drc": "συμπιεστής δυναμικής εμβέλειας",
+	"ml_ss": "παράβλεψη σιωπής", //m
 
 	"mt_loop": "επανάληψη ενός τραγουδιού\">🔁",
 	"mt_one": "σταμάτα μετά από ένα τραγούδι\">1️⃣",
@@ -318,8 +319,14 @@ Ls.grc = {
 	"mt_c2ng": "η συσκευή σου φαίνεται να μην υποστηρίζει αυτήν τη μορφή εξόδου, αλλά ας το δοκιμάσουμε ούτως ή άλλως",
 	"mt_xowa": "υπάρχουν bugs σε iOS που εμποδίζουν την αναπαραγωγή στο παρασκήνιο με αυτήν τη μορφή· χρησιμοποίησε caf ή mp3 αντ’ αυτού",
 	"mt_tint": "επίπεδο φόντου (0-100) στην μπάρα αναζήτησης$Nγια να κάνεις το buffering λιγότερο ενοχλητικό",
-	"mt_eq": "ενεργοποιεί τον ισοσταθμιστή και τον έλεγχο ενίσχυσης;$N$Nενίσχυση &lt;code&gt;0&lt;/code&gt; = στάνταρ 100% ένταση (απαράλλαχτη)$N$Nεύρος &lt;code&gt;1 &nbsp;&lt;/code&gt; = στάνταρ στερεοφωνικό (απαράλλαχτο)$Nεύρος &lt;code&gt;0.5&lt;/code&gt; = 50% αριστερά-δεξιά μίξη ήχου$Nεύρος &lt;code&gt;0 &nbsp;&lt;/code&gt; = μονοφωνικό$N$Nενίσχυση &lt;code&gt;-0.8&lt;/code&gt; &amp; εύρος &lt;code&gt;10&lt;/code&gt; = αφαίρεση φωνής :^)$N$Nη ενεργοποίηση του ισοσταθμιστή κάνει τα άλμπουμ χωρίς κενά, να παίζουν χωρίς καθόλου κενά, οπότε άφησέ το ενεργό με όλες τις τιμές στο μηδέν (εκτός από εύρος = 1) αν σε νοιάζει",
+	"mt_eq": "`ενεργοποιεί τον ισοσταθμιστή και τον έλεγχο ενίσχυσης;$N$Nενίσχυση `0` = στάνταρ 100% ένταση (απαράλλαχτη)$N$Nεύρος `1 &nbsp;` = στάνταρ στερεοφωνικό (απαράλλαχτο)$Nεύρος `0.5` = 50% αριστερά-δεξιά μίξη ήχου$Nεύρος `0 &nbsp;` = μονοφωνικό$N$Nενίσχυση `-0.8` &amp; εύρος `10` = αφαίρεση φωνής :^)$N$Nη ενεργοποίηση του ισοσταθμιστή κάνει τα άλμπουμ χωρίς κενά, να παίζουν χωρίς καθόλου κενά, οπότε άφησέ το ενεργό με όλες τις τιμές στο μηδέν (εκτός από εύρος = 1) αν σε νοιάζει",
 	"mt_drc": "ενεργοποιεί τον συμπιεστή δυναμικής εμβέλειας (εξομάλυνση έντασης / ακραία συμπίεση έντασης); θα ενεργοποιήσει και τον ισοσταθμιστή για να ισορροπήσει τον ήχο, οπότε βάλε όλα τα πεδία ισοσταθμιστή εκτός από το 'εύρος' στο 0 αν δεν το θες$N$Nχαμηλώνει την ένταση του ήχου πάνω από το όριο (THRESHOLD) dB; για κάθε RATIO dB πέρα από το όριο υπάρχει 1 dB εξόδου, οπότε οι προεπιλεγμένες τιμές όριο -24 και 'λόγος' 12 σημαίνουν ότι δεν θα ξεπεράσει ποτέ τα -22 dB και είναι ασφαλές να αυξήσεις την ενίσχυση ισοσταθμιστή σε 0.8, ή και 1.8 με ATK 0 και μεγάλο RLS όπως 90 (δουλεύει μόνο σε firefox· το RLS είναι max 1 σε άλλους browsers)$N$N(δες wikipedia, το εξηγούν καλύτερα)",
+	"mt_ss": "`ἐνεργοποιεῖ τὴν παράλειψιν σιγῆς· πολλαπλασιάζει τὴν ταχύτητα διὰ `ταχ` πλησίον ἀρχῆς/τέλους, ὅταν ἡ φωνὴ ὑπὸ `φων` καὶ ἡ θέσις ἐν τοῖς πρώτοις `ἀρχ`% ἢ τελευταίοις `τελ`%", //m
+	"mt_ssvt": "ὅριον φωνῆς (0-255)\">φων", //m
+	"mt_ssts": "ἐνεργὸν ὅριον (% τροχιᾶς, ἀρχή)\">ἀρχ", //m
+	"mt_sste": "ἐνεργὸν ὅριον (% τροχιᾶς, τέλος)\">τελ", //m
+	"mt_ssrt": "χρόνος αὔξησης/μείωσης φωνῆς/ταχύτητος\">σβέσις", //m
+	"mt_sssm": "πολλαπλασιαστὴς ταχύτητος\">ταχ", //m
 
 	"mb_play": "παίξε",
 	"mm_hashplay": "να παίξω αυτό το αρχείο ήχου;",
@@ -398,8 +405,8 @@ Ls.grc = {
 	"fr_case": "regex με διάκριση πεζών/κεφαλαίων\">case",
 	"fr_win": "ασφαλή ονόματα για windows; αντικαθιστά <code>&lt;&gt;:&quot;\\|?*</code> με ιαπωνικούς χαρακτήρες πλήρους πλάτους\">win",
 	"fr_slash": "αντικαθίσταται <code>/</code> με χαρακτήρα που δεν δημιουργεί νέους φακέλους\">όχι /",
-	"fr_re": "μοτίβα αναζήτησης (regex) για αναζήτηση στα αρχικά ονόματα; τα καταγραφόμενα groups μπορούν να χρησιμοποιηθούν στο πεδίο μορφοποίησης παρακάτω όπως &lt;code&gt;(1)&lt;/code&gt; και &lt;code&gt;(2)&lt;/code&gt; και ούτω καθεξής",
-	"fr_fmt": "εμπνευσμένο από foobar2000:$N&lt;code&gt;(title)&lt;/code&gt; αντικαθίσταται από τίτλο τραγουδιού,$N&lt;code&gt;[(artist) - ](title)&lt;/code&gt; παραλείπει το [this] αν το artist είναι κενό$N&lt;code&gt;$lpad((tn),2,0)&lt;/code&gt; γεμίζει τον αριθμό κομματιού σε 2 ψηφία",
+	"fr_re": "`μοτίβα αναζήτησης (regex) για αναζήτηση στα αρχικά ονόματα; τα καταγραφόμενα groups μπορούν να χρησιμοποιηθούν στο πεδίο μορφοποίησης παρακάτω όπως `(1)` και `(2)` και ούτω καθεξής",
+	"fr_fmt": "`εμπνευσμένο από foobar2000:$N`(title)` αντικαθίσταται από τίτλο τραγουδιού,$N`[(artist) - ](title)` παραλείπει το [this] αν το artist είναι κενό$N`$lpad((tn),2,0)` γεμίζει τον αριθμό κομματιού σε 2 ψηφία",
 	"fr_pdel": "διαγραφή",
 	"fr_pnew": "αποθήκευση ως",
 	"fr_pname": "δώσε όνομα για τη νέα προεπιλογή",
@@ -448,7 +455,7 @@ Ls.grc = {
 
 	"mk_noname": "γράψε ένα όνομα στο πεδίο κειμένου αριστερά πριν το κάνεις :p",
 	"nmd_i1": "μπορείτε επίσης να προσθέσετε την κατάληξη που θέλετε, όπως <code>.md</code>", //m
-	"nmd_i2": "μπορείτε να δημιουργήσετε μόνο αρχεία <code>.md</code> επειδή δεν έχετε δικαίωμα διαγραφής", //m
+	"nmd_i2": "μπορείτε να δημιουργήσετε μόνο αρχεία <code>.{0}</code> επειδή δεν έχετε δικαίωμα διαγραφής", //m
 
 	"tv_load": "Φόρτωση αρχείου κειμένου:\n\n{0}\n\n{1}% ({2} από {3} MiB φορτωμένα)",
 	"tv_xe1": "αδυναμία φόρτωσης αρχείου κειμένου:\n\nσφάλμα ",
