@@ -114,7 +114,7 @@ Ls.jpn = {
 	"login": "ログイン",
 	"access": " アクセス",
 	"ot_close": "サブメニューを閉じる",
-	"ot_search": "属性、パス/名前、音楽タグ、またはそれらの組み合わせでファイルを検索$N$N&lt;code&gt;foo bar&lt;/code&gt; = «foo» と «bar» の両方を含める。$N&lt;code&gt;foo -bar&lt;/code&gt; = «foo» を含み、«bar» を含まない必要があります。$N&lt;code&gt;^yana .opus$&lt;/code&gt; = «yana» で始まり、«opus» ファイルである$N&lt;code&gt;&quot;try unite&quot;&lt;/code&gt; = «try unite» だけを含む$N$N日付形式は iso-8601。たとえば、$N&lt;code&gt;2009-12-31&lt;/code&gt; や &lt;code&gt;2020-09-12 23:30:00&lt;/code&gt;",
+	"ot_search": "`属性、パス/名前、音楽タグ、またはそれらの組み合わせでファイルを検索$N$N`foo bar` = «foo» と «bar» の両方を含める。$N`foo -bar` = «foo» を含み、«bar» を含まない必要があります。$N`^yana .opus$` = «yana» で始まり、«opus» ファイルである$N`&quot;try unite&quot;` = «try unite» だけを含む$N$N日付形式は iso-8601。たとえば、$N`2009-12-31` や `2020-09-12 23:30:00`",
 	"ot_unpost": "unpost: 最近アップロードした投稿を削除するか、未完成の投稿を中止",
 	"ot_bup": "bup: 基本的なアップローダー。Netscape 4.0 もサポートしています。",
 	"ot_mkdir": "mkdir: 新しいディレクトリを作成",
@@ -263,9 +263,9 @@ Ls.jpn = {
 
 	"cdt_lim": "フォルダに表示するファイルの最大数",
 	"cdt_ask": "一番下までスクロールしたときに$N更にファイルを読み込む代わりに$N何をするか尋ねる",
-	"cdt_hsort": "メディアURLに含めるソートルール (&lt;code&gt;,sorthref&lt;/code&gt;) の数。0に設定するとメディアリンクをクリックした際にそのリンクに含まれるソートルールも無視されます。",
-	"cdt_ren": "カスタム右クリックメニューを有効にしてもShiftキーを押しながら右クリックすることで通常のメニューにアクセスできます。",
-	"cdt_rdb": "カスタム右クリックメニューが開いている状態で再度右クリックしたときに通常のメニューを表示する", //m
+	"cdt_hsort": "`メディアURLに含めるソートルール (`,sorthref`) の数。0に設定するとメディアリンクをクリックした際にそのリンクに含まれるソートルールも無視されます。",
+	"cdt_ren": "カスタム右クリックメニューを有効にしてもShiftキーを押しながら右クリックすることで通常のメニューにアクセスできます。\">有効",
+	"cdt_rdb": "カスタム右クリックメニューが開いている状態で再度右クリックしたときに通常のメニューを表示する\">x2", //m
 
 	"tt_entree": "ナビペインを表示（ディレクトリツリーサイドバー）$Nホットキー: B",
 	"tt_detree": "パンくずリストを表示$Nホットキー: B",
@@ -283,6 +283,7 @@ Ls.jpn = {
 	"ml_tint": "色合い",
 	"ml_eq": "オーディオイコライザー",
 	"ml_drc": "ダイナミックレンジコンプレッサー",
+	"ml_ss": "無音をスキップ", //m
 
 	"mt_loop": "1曲をループ/リピート再生\">🔁",
 	"mt_one": "1曲で止める\">1️⃣",
@@ -318,8 +319,14 @@ Ls.jpn = {
 	"mt_c2ng": "現在のデバイスはこの出力形式をサポートしていないようですが、とにかく試してみましょう",
 	"mt_xowa": "iOSにはこのフォーマットを使用したバックグラウンド再生を妨げるバグがあります; 代わりにcafまたはmp3を使用してください",
 	"mt_tint": "シークバーの背景レベル（0～100）を調整し$Nバッファリングの邪魔にならにようにする",
-	"mt_eq": "イコライザーとゲイン制御を有効にします;$N$Nブースト &lt;code&gt;0&lt;/code&gt; = 標準音量100%（変更なし）$N$N幅 &lt;code&gt;1 &nbsp;&lt;/code&gt; = 標準ステレオ（変更なし）$N幅 &lt;code&gt;0.5&lt;/code&gt; = 左右のクロスフィード50%$N幅 &lt;code&gt;0 &nbsp;&lt;/code&gt; = モノラル$N$Nブースト &lt;code&gt;-0.8&lt;/code&gt; &amp; 幅 &lt;code&gt;10&lt;/code&gt; = ボーカル除去 :^)$N$Nイコライザーを有効にするとギャップレスアルバムは完全にギャップレスになります。そのため、それを気に場合すべての値をゼロ（幅 = 1を除く）にしてイコライザーをオンにしたままにしてください。",
+	"mt_eq": "`イコライザーとゲイン制御を有効にします;$N$Nブースト `0` = 標準音量100%（変更なし）$N$N幅 `1 &nbsp;` = 標準ステレオ（変更なし）$N幅 `0.5` = 左右のクロスフィード50%$N幅 `0 &nbsp;` = モノラル$N$Nブースト `-0.8` &amp; 幅 `10` = ボーカル除去 :^)$N$Nイコライザーを有効にするとギャップレスアルバムは完全にギャップレスになります。そのため、それを気に場合すべての値をゼロ（幅 = 1を除く）にしてイコライザーをオンにしたままにしてください。",
 	"mt_drc": "ダイナミックレンジコンプレッサー（ボリュームフラットナー / ブリックウォーラー）を有効にします; EQでスパゲッティのバランスをとることもできます。そのため、EQのフィールドを「幅」以外すべて0に設定してください。$N$Nしきい値を超えるオーディオの音量を下げる; しきい値を超えるRATIO dBごとに1dBの出力されますしきい値-24と比率12のデフォルト値は、-22dBを超えることはなく、イコライザーのブーストを0.8に、またはATK 0とRLS 90などの非常に大きな値にした場合1.8まで安全に上げられます (Firefoxでのみ機能し、他のブラウザーではRLSは最大 1 です)。$N$N（Wikipedia を参照してください。もっとわかりやすく説明されています）",
+	"mt_ss": "`無音スキップを有効化；音量が `音` 未満で、再生位置が最初の `始`% または最後の `終`% にある場合、開始/終了付近で再生速度を `速` 倍します", //m
+	"mt_ssvt": "音量しきい値 (0-255)\">音", //m
+	"mt_ssts": "有効しきい値 (トラック%, 開始)\">始", //m
+	"mt_sste": "有効しきい値 (トラック%, 終了)\">終", //m
+	"mt_ssrt": "音量/速度 ランプ時間\">ﾌｪｰﾄﾞ", //m
+	"mt_sssm": "再生速度倍率\">速", //m
 
 	"mb_play": "再生",
 	"mm_hashplay": "このオーディオファイルを再生しますか？",
@@ -398,8 +405,8 @@ Ls.jpn = {
 	"fr_case": "大文字と小文字を区別する正規表現\">case",
 	"fr_win": "Windowsで安全な名前; <code>&lt;&gt;:&quot;\\|?*</code>を日本語の全角文字に置き換える\">win",
 	"fr_slash": "<code>/</code>を新しいフォルダが作成されない文字に置き換える\">no /",
-	"fr_re": "元のファイル名に適用する正規表現検索パターン; キャプチャグループは、&lt;code&gt;(1)&lt;/code&gt; や &lt;code&gt;(2)&lt;/code&gt; のように、以下のフォーマットフィールドで参照することができるので、",
-	"fr_fmt": "foob​​ar2000 を参考にしています:$N&lt;code&gt;(title)&lt;/code&gt; は曲名に置き換えられます。$N&lt;code&gt;[(artist) - ](title)&lt;/code&gt; はアーティストが空白の場合は[この]部分をスキップします。$N&lt;code&gt;$lpad((tn),2,0)&lt;/code&gt; はトラック番号を2桁にパディングします。",
+	"fr_re": "`元のファイル名に適用する正規表現検索パターン; キャプチャグループは、`(1)` や `(2)` のように、以下のフォーマットフィールドで参照することができるので、",
+	"fr_fmt": "`foob​​ar2000 を参考にしています:$N`(title)` は曲名に置き換えられます。$N`[(artist) - ](title)` はアーティストが空白の場合は[この]部分をスキップします。$N`$lpad((tn),2,0)` はトラック番号を2桁にパディングします。",
 	"fr_pdel": "削除",
 	"fr_pnew": "名前をつけて保存",
 	"fr_pname": "新しいプリセットの名前を入力します",
@@ -448,7 +455,7 @@ Ls.jpn = {
 
 	"mk_noname": "それをする前に左側のテキストフィールドに名前を入力してください :p",
 	"nmd_i1": "必要なファイル拡張子も追加します。例: <code>.md</code>",
-	"nmd_i2": "削除権限がないため、<code>.md</code> ファイルのみを作成できます",
+	"nmd_i2": "削除権限がないため、<code>.{0}</code> ファイルのみを作成できます",
 
 	"tv_load": "テキストドキュメントの読み込み中:\n\n{0}\n\n{1}%（{2} / {3} MiB ロード済み）",
 	"tv_xe1": "テキストファイルを読み込めませんでした:\n\nエラー ",
