@@ -114,7 +114,7 @@ Ls.kor = {
 	"login": "로그인", //m
 	"access": " 액세스",
 	"ot_close": "하위 메뉴 닫기",
-	"ot_search": "속성, 경로/이름, 음악 태그 또는 이들의 조합으로 파일을 검색합니다.$N$N&lt;code&gt;foo bar&lt;/code&gt; = «foo»와 «bar»를 모두 포함해야 함,$N&lt;code&gt;foo -bar&lt;/code&gt; = «foo»는 포함하지만 «bar»는 포함하지 않아야 함,$N&lt;code&gt;^yana .opus$&lt;/code&gt; = «yana»로 시작하고 «opus» 파일이어야 함$N&lt;code&gt;&quot;try unite&quot;&lt;/code&gt; = 정확히 «try unite»를 포함해야 함$N$N날짜 형식은 ISO-8601입니다. 예:$N&lt;code&gt;2009-12-31&lt;/code&gt; 또는 &lt;code&gt;2020-09-12 23:30:00&lt;/code&gt;",
+	"ot_search": "`속성, 경로/이름, 음악 태그 또는 이들의 조합으로 파일을 검색합니다.$N$N`foo bar` = «foo»와 «bar»를 모두 포함해야 함,$N`foo -bar` = «foo»는 포함하지만 «bar»는 포함하지 않아야 함,$N`^yana .opus$` = «yana»로 시작하고 «opus» 파일이어야 함$N`&quot;try unite&quot;` = 정확히 «try unite»를 포함해야 함$N$N날짜 형식은 ISO-8601입니다. 예:$N`2009-12-31` 또는 `2020-09-12 23:30:00`",
 	"ot_unpost": "주워담기: 최근 업로드한 항목을 삭제하거나 미완료된 업로드를 중단합니다",
 	"ot_bup": "bup: 기본 업로더. 넷스케이프 4.0도 지원합니다",
 	"ot_mkdir": "mkdir: 새 디렉터리를 만듭니다",
@@ -263,9 +263,9 @@ Ls.kor = {
 
 	"cdt_lim": "폴더에 표시할 최대 파일 수",
 	"cdt_ask": "맨 아래로 스크롤할 때$N더 많은 파일을 불러오는 대신$N무엇을 할지 묻기",
-	"cdt_hsort": "미디어 URL에 포함할 정렬 규칙 (&lt;code&gt;,sorthref&lt;/code&gt;)의 수. 0으로 설정하면 미디어 링크를 클릭할 때 포함된 정렬 규칙도 무시됩니다.",
-	"cdt_ren": "사용자 지정 우클릭 메뉴를 활성화합니다. shift 키를 누른 채 우클릭하면 기본 메뉴를 사용할 수 있습니다", //m
-	"cdt_rdb": "사용자 정의 우클릭 메뉴가 이미 열려 있을 때 다시 우클릭하면 기본 메뉴 표시", //m
+	"cdt_hsort": "`미디어 URL에 포함할 정렬 규칙 (`,sorthref`)의 수. 0으로 설정하면 미디어 링크를 클릭할 때 포함된 정렬 규칙도 무시됩니다.",
+	"cdt_ren": "사용자 지정 우클릭 메뉴를 활성화합니다. shift 키를 누른 채 우클릭하면 기본 메뉴를 사용할 수 있습니다\">활성화", //m
+	"cdt_rdb": "사용자 정의 우클릭 메뉴가 이미 열려 있을 때 다시 우클릭하면 기본 메뉴 표시\">x2", //m
 
 	"tt_entree": "탐색 창 (디렉터리 트리 사이드바) 표시$N단축키: B",
 	"tt_detree": "이동 경로 표시$N단축키: B",
@@ -283,6 +283,7 @@ Ls.kor = {
 	"ml_tint": "틴트",
 	"ml_eq": "오디오 이퀄라이저",
 	"ml_drc": "다이내믹 레인지 압축기",
+	"ml_ss": "무음 건너뛰기", //m
 
 	"mt_loop": "한 곡 반복 재생\">🔁",
 	"mt_one": "한 곡 재생 후 중지\">1️⃣",
@@ -318,8 +319,14 @@ Ls.kor = {
 	"mt_c2ng": "기기가 이 출력 형식을 지원하지 않는 것 같지만, 시도해 보겠습니다",
 	"mt_xowa": "iOS에서 이 형식의 백그라운드 재생이 안되는 버그가 있습니다. 대신 caf나 mp3를 사용해주세요.",
 	"mt_tint": "탐색 바의 배경 레벨 (0-100)$N버퍼링이 덜 눈시리게 만듦",
-	"mt_eq": "이퀄라이저 및 게인 제어 활성화;$N$Nboost &lt;code&gt;0&lt;/code&gt; = 표준 100% 볼륨 (수정 없음)$N$Nwidth &lt;code&gt;1 &nbsp;&lt;/code&gt; = 표준 스테레오 (수정 없음)$Nwidth &lt;code&gt;0.5&lt;/code&gt; = 50% 좌우 크로스피드$Nwidth &lt;code&gt;0 &nbsp;&lt;/code&gt; = 모노$N$Nboost &lt;code&gt;-0.8&lt;/code&gt; &amp; width &lt;code&gt;10&lt;/code&gt; = 보컬 제거 :^)$N$N이퀄라이저를 활성화하면 끊김 없는 앨범이 온전히 끊김 없이 재생되므로, 그 점이 중요하다면 모든 값을 0으로 두고 (width=1 제외) 켜두세요.",
+	"mt_eq": "`이퀄라이저 및 게인 제어 활성화;$N$Nboost `0` = 표준 100% 볼륨 (수정 없음)$N$Nwidth `1 &nbsp;` = 표준 스테레오 (수정 없음)$Nwidth `0.5` = 50% 좌우 크로스피드$Nwidth `0 &nbsp;` = 모노$N$Nboost `-0.8` &amp; width `10` = 보컬 제거 :^)$N$N이퀄라이저를 활성화하면 끊김 없는 앨범이 온전히 끊김 없이 재생되므로, 그 점이 중요하다면 모든 값을 0으로 두고 (width=1 제외) 켜두세요.",
 	"mt_drc": "다이내믹 레인지 컴프레서(볼륨 평탄화/벽돌화)를 활성화합니다. 스파게티의 균형을 맞추기 위해 EQ도 활성화되므로, 원하지 않으면 'width'를 제외한 모든 EQ 필드를 0으로 설정하세요.$N$NTHRESHOLD dB 이상의 오디오 볼륨을 낮춥니다. THRESHOLD를 초과하는 모든 RATIO dB에 대해 1dB의 출력이 있으므로, 기본값인 tresh -24 및 ratio 12는 볼륨이 -22dB보다 커지지 않음을 의미하며, 이퀄라이저 부스트를 0.8 또는 ATK 0과 큰 RLS (예: 90)를 사용하여 1.8까지 안전하게 높일 수 있습니다 (firefox에서만 작동, 다른 브라우저에서는 RLS 최대 1).$N$N(위키백과를 참조하세요, 훨씬 더 잘 설명되어 있습니다)",
+	"mt_ss": "`무음 건너뛰기 활성화; 볼륨이 `음` 미만이고 위치가 처음 `시`% 또는 마지막 `끝`% 이내일 때 시작/끝 근처에서 재생 속도를 `고` 배로 합니다", //m
+	"mt_ssvt": "볼륨 임계값 (0-255)\">음", //m
+	"mt_ssts": "활성 임계값 (% 트랙, 시작)\">시", //m
+	"mt_sste": "활성 임계값 (% 트랙, 끝)\">끝", //m
+	"mt_ssrt": "볼륨/속도 램프 시간\">페이드", //m
+	"mt_sssm": "재생 속도 배율\">고", //m
 
 	"mb_play": "재생",
 	"mm_hashplay": "이 오디오 파일을 재생할까요?",
@@ -398,8 +405,8 @@ Ls.kor = {
 	"fr_case": "대소문자 구분 정규식\">대소문자",
 	"fr_win": "Windows 안전 이름; <code>&lt;&gt;:&quot;\\|?*</code>를 일본어 전각 문자로 바꿉니다\">win",
 	"fr_slash": "<code>/</code>를 새 폴더를 만들지 않는 문자로 바꿉니다\">/ 없음",
-	"fr_re": "원본 파일 이름에 적용할 정규식 검색 패턴; 캡처링 그룹은 아래 형식 필드에서 &lt;code&gt;(1)&lt;/code&gt;, &lt;code&gt;(2)&lt;/code&gt; 등으로 참조할 수 있습니다",
-	"fr_fmt": "foobar2000에서 영감을 받음:$N&lt;code&gt;(title)&lt;/code&gt;은(는) 곡 제목으로 대체됨,$N&lt;code&gt;[(artist) - ](title)&lt;/code&gt;은(는) 아티스트가 비어 있으면 [이] 부분을 건너뜀$N&lt;code&gt;$lpad((tn),2,0)&lt;/code&gt;은(는) 트랙 번호를 2자리로 채움",
+	"fr_re": "`원본 파일 이름에 적용할 정규식 검색 패턴; 캡처링 그룹은 아래 형식 필드에서 `(1)`, `(2)` 등으로 참조할 수 있습니다",
+	"fr_fmt": "`foobar2000에서 영감을 받음:$N`(title)`은(는) 곡 제목으로 대체됨,$N`[(artist) - ](title)`은(는) 아티스트가 비어 있으면 [이] 부분을 건너뜀$N`$lpad((tn),2,0)`은(는) 트랙 번호를 2자리로 채움",
 	"fr_pdel": "삭제",
 	"fr_pnew": "다른 이름으로 저장",
 	"fr_pname": "새 프리셋의 이름을 입력하세요",
@@ -448,7 +455,7 @@ Ls.kor = {
 
 	"mk_noname": "왼쪽 텍스트 필드에 이름을 먼저 입력해주세요 :p",
 	"nmd_i1": "원하는 파일 확장자를 추가할 수 있습니다. 예: <code>.md</code>", //m
-	"nmd_i2": "삭제 권한이 없어서 <code>.md</code> 파일만 만들 수 있습니다", //m
+	"nmd_i2": "삭제 권한이 없어서 <code>.{0}</code> 파일만 만들 수 있습니다", //m
 
 	"tv_load": "텍스트 문서 불러오는 중:\n\n{0}\n\n{1}% ({3} MiB 중 {2} MiB 로드됨)",
 	"tv_xe1": "텍스트 파일을 불러올 수 없습니다:\n\n오류 ",
