@@ -114,7 +114,7 @@ Ls.rus = {
 	"login": "Войти", //m
 	"access": " доступ",
 	"ot_close": "закрыть подменю",
-	"ot_search": "искать файлы по атрибутам, пути / имени, музыкальным тегам или любой другой комбинации из следующих конструкций$N$N&lt;code&gt;foo bar&lt;/code&gt; = обязано содержать «foo» И «bar»,$N&lt;code&gt;foo -bar&lt;/code&gt; = обязано содержать «foo», но не «bar»,$N&lt;code&gt;^yana .opus$&lt;/code&gt; = начинается с «yana» и имеет расширение «opus»$N&lt;code&gt;&quot;try unite&quot;&lt;/code&gt; = содержит именно «try unite»$N$Nформат времени задаётся по стандарту iso-8601, например$N&lt;code&gt;2009-12-31&lt;/code&gt; или &lt;code&gt;2020-09-12 23:30:00&lt;/code&gt;",
+	"ot_search": "`искать файлы по атрибутам, пути / имени, музыкальным тегам или любой другой комбинации из следующих конструкций$N$N`foo bar` = обязано содержать «foo» И «bar»,$N`foo -bar` = обязано содержать «foo», но не «bar»,$N`^yana .opus$` = начинается с «yana» и имеет расширение «opus»$N`&quot;try unite&quot;` = содержит именно «try unite»$N$Nформат времени задаётся по стандарту iso-8601, например$N`2009-12-31` или `2020-09-12 23:30:00`",
 	"ot_unpost": "unpost: удалить ваши недавние загрузки и отменить незавершённые",
 	"ot_bup": "bup: легковесный загрузчик файлов, поддерживает даже netscape 4.0",
 	"ot_mkdir": "mkdir: создать новую папку",
@@ -263,9 +263,9 @@ Ls.rus = {
 
 	"cdt_lim": "максимальное количество файлов для показа в папке",
 	"cdt_ask": "внизу страницы спрашивать о действии вместо автоматической загрузки следующих файлов",
-	"cdt_hsort": "сколько правил сортировки (&lt;code&gt;,sorthref&lt;/code&gt;) включать в адрес страницы. Если значение равно 0, по нажатии на ссылки будут игнорироваться правила, включённые в них",
-	"cdt_ren": "включить настраиваемое контекстное меню, обычное меню доступно при нажатии shift и правой кнопки мыши", //m
-	"cdt_rdb": "показывать обычное меню правого клика, если пользовательское уже открыто и выполняется повторный клик", //m
+	"cdt_hsort": "`сколько правил сортировки (`,sorthref`) включать в адрес страницы. Если значение равно 0, по нажатии на ссылки будут игнорироваться правила, включённые в них",
+	"cdt_ren": "включить настраиваемое контекстное меню, обычное меню доступно при нажатии shift и правой кнопки мыши\">вкл.",
+	"cdt_rdb": "показывать обычное меню правого клика, если пользовательское уже открыто и выполняется повторный клик\">двойное",
 
 	"tt_entree": "показать панель навигации$NГорячая клавиша: B",
 	"tt_detree": "скрыть панель навигации$NГорячая клавиша: B",
@@ -283,6 +283,7 @@ Ls.rus = {
 	"ml_tint": "затемн.",
 	"ml_eq": "эквалайзер",
 	"ml_drc": "компрессор",
+	"ml_ss": "пропускать тишину", //m
 
 	"mt_loop": "повторять один трек\">🔁",
 	"mt_one": "остановить после этого трека\">1️⃣",
@@ -318,8 +319,14 @@ Ls.rus = {
 	"mt_c2ng": "не похоже, что ваше устройство поддерживает этот формат, но давайте попробуем и узнаем наверняка",
 	"mt_xowa": "в iOS есть баги, препятствующие фоновому воспроизведению этого формата. Пожалуйста, используйте caf или mp3",
 	"mt_tint": "непрозрачность фона (0-100) на полосе воспроизведения$N$Nделает буферизацию менее отвлекающей",
-	"mt_eq": "включить эквалайзер$N$Nboost &lt;code&gt;0&lt;/code&gt; = стандартная громкость$N$Nwidth &lt;code&gt;1 &nbsp;&lt;/code&gt; = обычное стерео$Nwidth &lt;code&gt;0.5&lt;/code&gt; = микширование левого и правого каналов на 50%$Nwidth &lt;code&gt;0 &nbsp;&lt;/code&gt; = моно$N$Nboost &lt;code&gt;-0.8&lt;/code&gt; и width &lt;code&gt;10&lt;/code&gt; = удаление голоса :^)$N$Nвключённый эквалайзер полностью убирает задержку между треками, поэтому следует его включить со всеми значениями на 0 (кроме width = 1), если вам нужно бесшовное воспроизведение",
+	"mt_eq": "`включить эквалайзер$N$Nboost `0` = стандартная громкость$N$Nwidth `1 &nbsp;` = обычное стерео$Nwidth `0.5` = микширование левого и правого каналов на 50%$Nwidth `0 &nbsp;` = моно$N$Nboost `-0.8` и width `10` = удаление голоса :^)$N$Nвключённый эквалайзер полностью убирает задержку между треками, поэтому следует его включить со всеми значениями на 0 (кроме width = 1), если вам нужно бесшовное воспроизведение",
 	"mt_drc": "включить компрессор; также включит эквалайзер для баланса вселенной, так что выставьте всё на 0 кроме width, если он вам не нужен$N$Nпонижает громкость при волне выше значения dB в tresh; каждый dB в ratio равен одному dB на выходе, так что стандартные значения tresh = -24 и ratio = 12 сделают так, что звук никогда не будет громче -22 dB. При таком раскладе можно поставить boost в эквалайзере на 0.8 или даже 1.8 при значении atk = 0 и огромном rls вроде 90 (работает только в Firefox, rls не может быть выше 1 в других браузерах)$N$N(загляните в википедию, там всё объяснено подробнее)",
+	"mt_ss": "`включает пропуск тишины; умножает скорость на `уск` возле начала/конца, когда громкость ниже `гром` и позиция в первых `нач`% или последних `кон`%", //m
+	"mt_ssvt": "порог громкости (0-255)\">гром", //m
+	"mt_ssts": "активный порог (% трека, начало)\">нач", //m
+	"mt_sste": "активный порог (% трека, конец)\">кон", //m
+	"mt_ssrt": "время нарастания/спада громк./скор.\">фейд", //m
+	"mt_sssm": "множитель скорости воспроизведения\">уск", //m
 
 	"mb_play": "играть",
 	"mm_hashplay": "воспроизвести этот музыкальный файл?",
@@ -398,8 +405,8 @@ Ls.rus = {
 	"fr_case": "чувствительный к регистру regex\">РеГиСтР",
 	"fr_win": "совместимые с windows имена; заменяет <code>&lt;&gt;:&quot;\\|?*</code> японскими полноширинными символами\">win",
 	"fr_slash": "заменяет <code>/</code> символом, который не создаёт новые папки\">без /",
-	"fr_re": "поиск по шаблону regex, применяемый к оригинальным именам; группы захвата могут применяться в поле форматирования с помощью &lt;code&gt;(1)&lt;/code&gt; и &lt;code&gt;(2)&lt;/code&gt; и так далее",
-	"fr_fmt": "вдохновлено foobar2000:$N&lt;code&gt;(title)&lt;/code&gt; заменяется названием трека,$N&lt;code&gt;[(artist) - ](title)&lt;/code&gt; пропускает [эту] часть, если композитор не указан$N&lt;code&gt;$lpad((tn),2,0)&lt;/code&gt; добавляет ведущие нули до двух цифр",
+	"fr_re": "`поиск по шаблону regex, применяемый к оригинальным именам; группы захвата могут применяться в поле форматирования с помощью `(1)` и `(2)` и так далее",
+	"fr_fmt": "`вдохновлено foobar2000:$N`(title)` заменяется названием трека,$N`[(artist) - ](title)` пропускает [эту] часть, если композитор не указан$N`$lpad((tn),2,0)` добавляет ведущие нули до двух цифр",
 	"fr_pdel": "удалить",
 	"fr_pnew": "сохранить как",
 	"fr_pname": "предоставьте название для нового шаблона",
@@ -448,7 +455,7 @@ Ls.rus = {
 
 	"mk_noname": "введите имя в текстовое поле слева перед тем, как это делать :p",
 	"nmd_i1": "вы также можете указать нужное расширение, например <code>.md</code>", //m
-	"nmd_i2": "вы можете создавать только файлы <code>.md</code>, так как у вас нет разрешения на удаление", //m
+	"nmd_i2": "вы можете создавать только файлы <code>.{0}</code>, так как у вас нет разрешения на удаление", //m
 
 	"tv_load": "Загружаю текстовый документ:\n\n{0}\n\n{1}% ({2} из {3} МиБ загружено)",
 	"tv_xe1": "не удалось загрузить текстовый файл:\n\nошибка ",
