@@ -114,7 +114,7 @@ Ls.swe = {
 	"login": "Logga in", //m
 	"access": "-rättighet",
 	"ot_close": "stäng undermeny",
-	"ot_search": "sök efter filer via attribut, sökväg / namn, musiktaggar, eller någon kombination av dessa$N$N&lt;code&gt;foo bar&lt;/code&gt; = måste innehålla både «foo» och «bar»,$N&lt;code&gt;foo -bar&lt;/code&gt; = måste innehålla «foo» men inte «bar»,$N&lt;code&gt;^yana .opus$&lt;/code&gt; = måste börja med «yana» och vara en «opus»-fil$N&lt;code&gt;&quot;try unite&quot;&lt;/code&gt; = måste innehålla exakt «try unite»$N$Ndatumformatet är iso-8601, t.ex.$N&lt;code&gt;2009-12-31&lt;/code&gt; eller &lt;code&gt;2020-09-12 23:30:00&lt;/code&gt;",
+	"ot_search": "`sök efter filer via attribut, sökväg / namn, musiktaggar, eller någon kombination av dessa$N$N`foo bar` = måste innehålla både «foo» och «bar»,$N`foo -bar` = måste innehålla «foo» men inte «bar»,$N`^yana .opus$` = måste börja med «yana» och vara en «opus»-fil$N`&quot;try unite&quot;` = måste innehålla exakt «try unite»$N$Ndatumformatet är iso-8601, t.ex.$N`2009-12-31` eller `2020-09-12 23:30:00`",
 	"ot_unpost": "unpost: radera dina senaste uppladdningar, eller avbryt pågående sådana",
 	"ot_bup": "bup: enkel uppladdare, stödjer t o m netscape 4.0",
 	"ot_mkdir": "mkdir: skapa en ny mapp",
@@ -263,9 +263,9 @@ Ls.swe = {
 
 	"cdt_lim": "högsta antal filer att visa in en mapp",
 	"cdt_ask": "när du når botten av vyn,$Nbe om en åtgärd istället för att ladda fler filer",
-	"cdt_hsort": "hur många sorteringsregler (&lt;code&gt;,sorthref&lt;/code&gt;) att inkludera i media-URL:er. Sätts detta till 0 kommer regler i klickade medialänkar även att ignoreras",
-	"cdt_ren": "aktivera anpassad högerklicksmeny, den vanliga menyn är tillgänglig med shift + högerklick", //m
-	"cdt_rdb": "visa den vanliga högerklicksmenyn när den anpassade redan är öppen och man högerklickar igen", //m
+	"cdt_hsort": "`hur många sorteringsregler (`,sorthref`) att inkludera i media-URL:er. Sätts detta till 0 kommer regler i klickade medialänkar även att ignoreras",
+	"cdt_ren": "aktivera anpassad högerklicksmeny, den vanliga menyn är tillgänglig med shift + högerklick\">aktivera", //m
+	"cdt_rdb": "visa den vanliga högerklicksmenyn när den anpassade redan är öppen och man högerklickar igen\">x2", //m
 
 	"tt_entree": "visa trädvy$NSnabbtangent: B",
 	"tt_detree": "visa brödsmulor$NSnabbtangent: B",
@@ -283,6 +283,7 @@ Ls.swe = {
 	"ml_tint": "hy",
 	"ml_eq": "ljudutjämnare",
 	"ml_drc": "dynamikkompressor",
+	"ml_ss": "hoppa över tystnad", //m
 
 	"mt_loop": "upprepa en låt\">🔁",
 	"mt_one": "stoppa uppspelningen efter en låt\">1️⃣",
@@ -318,8 +319,14 @@ Ls.swe = {
 	"mt_c2ng": "din enhet verkar inte stödja det här formatet, men vi provar ändå",
 	"mt_xowa": "det finns buggar i iOS som hindrar uppspelning i bakgrunden med detta format; vänligen använd caf eller mp3 istället",
 	"mt_tint": "nivå på bakgrundsfärg (0-100) på uppspelningsreglaget;$Ngör buffring mindre distraherande",
-	"mt_eq": "aktiverar utjämning och förstärkning;$N$Nboost &lt;code&gt;0&lt;/code&gt; = standard 100%-volym (omodifierad)$N$Nwidth &lt;code&gt;1 &nbsp;&lt;/code&gt; = standard stereo (omodifierad)$Nwidth &lt;code&gt;0.5&lt;/code&gt; = 50% vänster-höger crossfeed$Nwidth &lt;code&gt;0 &nbsp;&lt;/code&gt; = mono$N$Nboost &lt;code&gt;-0.8&lt;/code&gt; &amp; width &lt;code&gt;10&lt;/code&gt; = tar bort sång :^)$N$Nnär utjämningen är aktiverad blir gaplösa album verkligen gaplösa, så låt den stå påslagen med alla värden satta till 0 (förutom width = 1) om du bryr dig om det",
+	"mt_eq": "`aktiverar utjämning och förstärkning;$N$Nboost `0` = standard 100%-volym (omodifierad)$N$Nwidth `1 &nbsp;` = standard stereo (omodifierad)$Nwidth `0.5` = 50% vänster-höger crossfeed$Nwidth `0 &nbsp;` = mono$N$Nboost `-0.8` &amp; width `10` = tar bort sång :^)$N$Nnär utjämningen är aktiverad blir gaplösa album verkligen gaplösa, så låt den stå påslagen med alla värden satta till 0 (förutom width = 1) om du bryr dig om det",
 	"mt_drc": "aktiverar dynamikkompressorn (volymtillplattning / brickwaller); aktiverar även utjämnaren för att balansera röran, så sätt alla fält i utjämnaren förutom 'width' till 0 om du inte vill ha den$N$Nsänker all volym över THRESHOLD dB; för varje RATIO dB över THRESHOLD blir det 1 dB av output, så standardvärdena tresh = -24 och ratio = 12 innebär att volymen aldrig bör bli högre än -22 dB och det är säkert att höja utjämnarens boost till 0.8, eller t.o.m. 1.8 med ATK 0 och ett högt RLS-värde t.ex. 90 (fungerar endast i firefox; RLS är låst till högst 1 i andra webbläsare)$N$N(se wikipedia för en bättre förklaring)",
+	"mt_ss": "`aktiverar tystnadshopp; multiplicerar uppspelningshastigheten med `sn` nära start/slut när volymen är under `vol` och positionen är inom första `sta`% eller sista `slt`%", //m
+	"mt_ssvt": "volymtröskel (0-255)\">vol", //m
+	"mt_ssts": "aktiv tröskel (% spår, start)\">sta", //m
+	"mt_sste": "aktiv tröskel (% spår, slut)\">slt", //m
+	"mt_ssrt": "upp/ned-rampningstid volym/hastighet\">fade", //m
+	"mt_sssm": "uppspelningshastighetsmultiplikator\">sn", //m
 
 	"mb_play": "play",
 	"mm_hashplay": "spela upp den här ljudfilen?",
@@ -398,8 +405,8 @@ Ls.swe = {
 	"fr_case": "skiftlägeskänsligt reguljärt uttryck\">skift",
 	"fr_win": "windows-säkra namn; ersätt <code>&lt;&gt;:&quot;\\|?*</code> med japanska fullbreddtecken\">win",
 	"fr_slash": "ersätt <code>/</code> med ett tecken som inte skapar nya mappar\">ingen /",
-	"fr_re": "reguljärt sökuttryck att tillämpa på ursprungliga filnamn; grupper kan hänvisas till i formatfältet nedan via &lt;code&gt;(1)&lt;/code&gt; och &lt;code&gt;(2)&lt;/code&gt; osv.",
-	"fr_fmt": "inspirerat av foobar2000:$N&lt;code&gt;(title)&lt;/code&gt; ersätts av låttitel,$N&lt;code&gt;[(artist) - ](title)&lt;/code&gt; skippar [detta] om artisten är tom$N&lt;code&gt;$lpad((tn),2,0)&lt;/code&gt; fyller i spårnumret till 2 siffror",
+	"fr_re": "`reguljärt sökuttryck att tillämpa på ursprungliga filnamn; grupper kan hänvisas till i formatfältet nedan via `(1)` och `(2)` osv.",
+	"fr_fmt": "`inspirerat av foobar2000:$N`(title)` ersätts av låttitel,$N`[(artist) - ](title)` skippar [detta] om artisten är tom$N`$lpad((tn),2,0)` fyller i spårnumret till 2 siffror",
 	"fr_pdel": "ta bort",
 	"fr_pnew": "spara som",
 	"fr_pname": "ge ett nytt namn på din inställning",
@@ -448,7 +455,7 @@ Ls.swe = {
 
 	"mk_noname": "skriv ett namn i fältet till vänster först :p",
 	"nmd_i1": "lägg också till filändelsen du vill ha, till exempel <code>.md</code>", //m
-	"nmd_i2": "du kan bara skapa <code>.md</code>-filer eftersom du inte har borttagningsbehörighet", //m
+	"nmd_i2": "du kan bara skapa <code>.{0}</code>-filer eftersom du inte har borttagningsbehörighet", //m
 
 	"tv_load": "Laddar textfil:\n\n{0}\n\n{1}% ({2} av {3} MiB laddat)",
 	"tv_xe1": "kunde ej ladda textfil:\n\nfel ",
