@@ -114,7 +114,7 @@ Ls.ukr = {
 	"login": "увійти", //m
 	"access": " доступ",
 	"ot_close": "закрити підменю",
-	"ot_search": "пошук файлів за атрибутами, шляхом / іменем, музичними тегами, або будь-якою комбінацією$N$N&lt;code&gt;foo bar&lt;/code&gt; = має містити «foo» і «bar»,$N&lt;code&gt;foo -bar&lt;/code&gt; = має містити «foo», але не «bar»,$N&lt;code&gt;^yana .opus$&lt;/code&gt; = починатися з «yana» і бути файлом «opus»$N&lt;code&gt;&quot;try unite&quot;&lt;/code&gt; = містити точно «try unite»$N$Nформат дати - iso-8601, наприклад$N&lt;code&gt;2009-12-31&lt;/code&gt; або &lt;code&gt;2020-09-12 23:30:00&lt;/code&gt;",
+	"ot_search": "`пошук файлів за атрибутами, шляхом / іменем, музичними тегами, або будь-якою комбінацією$N$N`foo bar` = має містити «foo» і «bar»,$N`foo -bar` = має містити «foo», але не «bar»,$N`^yana .opus$` = починатися з «yana» і бути файлом «opus»$N`&quot;try unite&quot;` = містити точно «try unite»$N$Nформат дати - iso-8601, наприклад$N`2009-12-31` або `2020-09-12 23:30:00`",
 	"ot_unpost": "скасувати: видалити недавні завантаження або перервати незавершені",
 	"ot_bup": "bup: основний завантажувач, підтримує навіть netscape 4.0",
 	"ot_mkdir": "mkdir: створити нову папку",
@@ -263,9 +263,9 @@ Ls.ukr = {
 
 	"cdt_lim": "максимальна кількість файлів для показу в папці",
 	"cdt_ask": "при прокрутці до низу,$Nзамість завантаження більше файлів,$Nзапитати, що робити",
-	"cdt_hsort": "скільки правил сортування (&lt;code&gt;,sorthref&lt;/code&gt;) включати в медіа-URL. Встановлення цього в 0 також буде ігнорувати правила сортування, включені в медіа посилання при їх натисканні",
-	"cdt_ren": "увімкнути користувацьке контекстне меню, звичайне меню доступне при натисканні shift і правої кнопки миші", //m
-	"cdt_rdb": "показувати звичайне меню правої кнопки, якщо власне меню вже відкрите і відбувається повторне клацання", //m
+	"cdt_hsort": "`скільки правил сортування (`,sorthref`) включати в медіа-URL. Встановлення цього в 0 також буде ігнорувати правила сортування, включені в медіа посилання при їх натисканні",
+	"cdt_ren": "увімкнути користувацьке контекстне меню, звичайне меню доступне при натисканні shift і правої кнопки миші\">увімкнути", //m
+	"cdt_rdb": "показувати звичайне меню правої кнопки, якщо власне меню вже відкрите і відбувається повторне клацання\">x2", //m
 
 	"tt_entree": "показати панель навігації (бічна панель дерева каталогів)$NГаряча клавіша: B",
 	"tt_detree": "показати хлібні крихти$NГаряча клавіша: B",
@@ -283,6 +283,7 @@ Ls.ukr = {
 	"ml_tint": "відтінок",
 	"ml_eq": "аудіо еквалайзер",
 	"ml_drc": "компресор динамічного діапазону",
+	"ml_ss": "пропускати тишу", //m
 
 	"mt_loop": "зациклити/повторити одну пісню\">🔁",
 	"mt_one": "зупинити після однієї пісні\">1️⃣",
@@ -318,8 +319,14 @@ Ls.ukr = {
 	"mt_c2ng": "ваш пристрій, здається, не підтримує цей вихідний формат, але давайте все одно спробуємо",
 	"mt_xowa": "є баги в iOS, які запобігають фоновому відтворенню з використанням цього формату; будь ласка, використовуйте caf або mp3 замість цього",
 	"mt_tint": "рівень фону (0-100) на смузі перемотування$Nщоб зробити буферизацію менш відвертаючою",
-	"mt_eq": "вмикає еквалайзер і контроль посилення;$N$Nпосилення &lt;code&gt;0&lt;/code&gt; = стандартна 100% гучність (немодифікована)$N$Nширина &lt;code&gt;1 &nbsp;&lt;/code&gt; = стандартне стерео (немодифіковане)$Nширина &lt;code&gt;0.5&lt;/code&gt; = 50% перехресне живлення ліво-право$Nширина &lt;code&gt;0 &nbsp;&lt;/code&gt; = моно$N$Nпосилення &lt;code&gt;-0.8&lt;/code&gt; &amp; ширина &lt;code&gt;10&lt;/code&gt; = видалення вокалу :^)$N$Nвключення еквалайзера робить безшовні альбоми повністю безшовними, тому залишайте його увімкненим з усіма значеннями в нулі (окрім ширини = 1), якщо вам це важливо",
+	"mt_eq": "`вмикає еквалайзер і контроль посилення;$N$Nпосилення `0` = стандартна 100% гучність (немодифікована)$N$Nширина `1 &nbsp;` = стандартне стерео (немодифіковане)$Nширина `0.5` = 50% перехресне живлення ліво-право$Nширина `0 &nbsp;` = моно$N$Nпосилення `-0.8` &amp; ширина `10` = видалення вокалу :^)$N$Nвключення еквалайзера робить безшовні альбоми повністю безшовними, тому залишайте його увімкненим з усіма значеннями в нулі (окрім ширини = 1), якщо вам це важливо",
 	"mt_drc": "вмикає компресор динамічного діапазону (вирівнювач гучності / цегловий вал); також увімкне EQ для балансування спагеті, тому встановіть всі поля EQ окрім 'width' в 0, якщо ви цього не хочете$N$Nзнижує гучність аудіо вище THRESHOLD дБ; для кожного RATIO дБ понад THRESHOLD є 1 дБ виходу, тому стандартні значення tresh -24 і ratio 12 означають, що він ніколи не повинен стати гучнішим за -22 дБ і безпечно збільшити посилення еквалайзера до 0.8, або навіть 1.8 з ATK 0 і величезним RLS як 90 (працює тільки в firefox; RLS максимум 1 в інших браузерах)$N$N(дивіться вікіпедію, вони пояснюють це набагато краще)",
+	"mt_ss": "`вмикає пропуск тиші; множить швидкість на `шв` біля початку/кінця, коли гучність нижче `гуч` і позиція в перших `поч`% або останніх `кін`%", //m
+	"mt_ssvt": "поріг гучності (0-255)\">гуч", //m
+	"mt_ssts": "активний поріг (% треку, початок)\">поч", //m
+	"mt_sste": "активний поріг (% треку, кінець)\">кін", //m
+	"mt_ssrt": "час нарост./спаду гучн./швидк.\">фейд", //m
+	"mt_sssm": "множник швидкості відтворення\">шв", //m
 
 	"mb_play": "відтворити",
 	"mm_hashplay": "відтворити цей аудіо файл?",
@@ -398,8 +405,8 @@ Ls.ukr = {
 	"fr_case": "регулярний вираз з урахуванням регістру\">регістр",
 	"fr_win": "безпечні для windows імена; замінити <code>&lt;&gt;:&quot;\\|?*</code> на японські повноширинні символи\">win",
 	"fr_slash": "замінити <code>/</code> на символ, який не призводить до створення нових папок\">без /",
-	"fr_re": "шаблон пошуку регулярного виразу для застосування до оригінальних імен файлів; групи захоплення можна посилатися в полі формату нижче як &lt;code&gt;(1)&lt;/code&gt; і &lt;code&gt;(2)&lt;/code&gt; і так далі",
-	"fr_fmt": "натхненний foobar2000:$N&lt;code&gt;(title)&lt;/code&gt; замінюється назвою пісні,$N&lt;code&gt;[(artist) - ](title)&lt;/code&gt; пропускає [цю] частину, якщо виконавець порожній$N&lt;code&gt;$lpad((tn),2,0)&lt;/code&gt; доповнює номер треку до 2 цифр",
+	"fr_re": "`шаблон пошуку регулярного виразу для застосування до оригінальних імен файлів; групи захоплення можна посилатися в полі формату нижче як `(1)` і `(2)` і так далі",
+	"fr_fmt": "`натхненний foobar2000:$N`(title)` замінюється назвою пісні,$N`[(artist) - ](title)` пропускає [цю] частину, якщо виконавець порожній$N`$lpad((tn),2,0)` доповнює номер треку до 2 цифр",
 	"fr_pdel": "видалити",
 	"fr_pnew": "зберегти як",
 	"fr_pname": "надайте ім'я для вашого нового пресету",
@@ -448,7 +455,7 @@ Ls.ukr = {
 
 	"mk_noname": "введіть ім'я в текстове поле зліва перед тим, як робити це :p",
 	"nmd_i1": "ви також можете додати потрібне розширення, наприклад <code>.md</code>", //m
-	"nmd_i2": "ви можете створювати тільки файли <code>.md</code>, оскільки не маєте дозволу на видалення", //m
+	"nmd_i2": "ви можете створювати тільки файли <code>.{0}</code>, оскільки не маєте дозволу на видалення", //m
 
 	"tv_load": "Завантаження текстового документа:\n\n{0}\n\n{1}% ({2} з {3} MiB завантажено)",
 	"tv_xe1": "не вдалося завантажити текстовий файл:\n\nпомилка ",
